@@ -1,7 +1,7 @@
 """Test attribute selector."""
 from .. import util
 from soupsieve import SelectorSyntaxError
-from bs4 import BeautifulSoup as BS
+from bs4 import BeautifulSoup
 
 
 class TestAttribute(util.TestCase):
@@ -375,14 +375,14 @@ class TestAttribute(util.TestCase):
     def test_none_inputs(self):
         """Test weird inputs."""
 
-        soup = BS('<span>text</span>', 'html.parser')
+        soup = BeautifulSoup('<span>text</span>', 'html.parser')
         soup.span['foo'] = None
         self.assertEqual(len(soup.select('span[foo]')), 1)
 
     def test_numeric_inputs(self):
         """Test weird inputs."""
 
-        soup = BS('<span>text</span>', 'html.parser')
+        soup = BeautifulSoup('<span>text</span>', 'html.parser')
         soup.span['foo'] = 3
         self.assertEqual(len(soup.select('span[foo="3"]')), 1)
         soup.span['foo'] = 3.3
@@ -391,29 +391,29 @@ class TestAttribute(util.TestCase):
     def test_sequence_inputs(self):
         """Test weird inputs."""
 
-        soup = BS('<span>text</span>', 'html.parser')
+        soup = BeautifulSoup('<span>text</span>', 'html.parser')
         soup.span['foo'] = [3, "4"]
         self.assertEqual(len(soup.select('span[foo="3 4"]')), 1)
 
     def test_bytes_inputs(self):
         """Test weird inputs."""
 
-        soup = BS('<span>text</span>', 'html.parser')
+        soup = BeautifulSoup('<span>text</span>', 'html.parser')
         soup.span['foo'] = b'test'
         self.assertEqual(len(soup.select('span[foo="test"]')), 1)
 
     def test_weird_inputs(self):
         """Test weird inputs."""
 
-        soup = BS('<span>text</span>', 'html.parser')
+        soup = BeautifulSoup('<span>text</span>', 'html.parser')
         soup.span['foo'] = {'3': '4'}
         self.assertEqual(len(soup.select('span[foo="{\'3\': \'4\'}"]')), 1)
 
     def test_nested_sequences(self):
-        """Nested sequences will crash and burn due to the way BS handles them."""
+        """Nested sequences will crash and burn due to the way BeautifulSoup handles them."""
 
         # The exact exception is not important as it can fail in various locations for different reasons
-        with self.assertRaises(Exception):
-            soup = BS('<span>text</span>', 'html.parser')
+        with self.assertRaises(Exception):  # noqa: B017
+            soup = BeautifulSoup('<span>text</span>', 'html.parser')
             soup.span['foo'] = [['1']]
             soup.select("span['foo']")
